@@ -8,12 +8,13 @@ class Tabs(_Tabs):
     def __init__(self, names: Union[Iterable[str], Dict[str, str]]) -> None:
         super().__init__()
         labels = []
-        if isinstance(names, list):
-            labels = [n for n in names]
+        if isinstance(names, Iterable):
+            names = [str(n) for n in names]
+            labels = names
 
         if isinstance(names, Dict):
-            labels = list(names.values())
-            names = list(names.keys())
+            labels = list(str(n) for n in names.values())
+            names = list(str(n) for n in names.keys())
 
         self._labels = labels
         self.names = names
